@@ -16,7 +16,9 @@
 
 """Functions for working with generic syntax URIs."""
 
-__version__ = '1.0.1'
+import pkg_resources
+__version__ = pkg_resources.resource_string(
+    "lazr.uri", "version.txt").strip()
 
 # Re-export in such a way that __version__ can still be imported if
 # dependencies are not yet available.
